@@ -18,12 +18,13 @@ def _checkClassifiers(testcase, installed):
     testcase.assertEqual(list(installed.classifiers),
                          [
       'Intended Audience :: Developers',
-      'License :: OSI Approved :: Python Software Foundation License',
+      'License :: OSI Approved :: MIT License',
       'Operating System :: OS Independent',
       'Programming Language :: Python :: 2.7',
-      'Programming Language :: Python :: 3.3',
-      'Programming Language :: Python :: 3.4',
       'Programming Language :: Python :: 3.5',
+      'Programming Language :: Python :: 3.6',
+      'Programming Language :: Python :: 3.7',
+      'Programming Language :: Python :: 3.8',
       'Programming Language :: Python :: Implementation :: CPython',
       'Programming Language :: Python :: Implementation :: PyPy',
       'Topic :: Software Development :: Libraries :: Python Modules',
@@ -32,7 +33,4 @@ def _checkClassifiers(testcase, installed):
 
 
 def _defaultMetadataVersion():
-    import sys
-    if sys.version_info[:2] > (2, 6):
-        return '1.1'
-    return '1.0'
+    return '2.1'
